# Devaa 
### Andrea Nicoletta - 2022 <br> <br> <br>

Documentation on [GitHub](https://github.com/Anico2/devaa)<br>


<br> <br>
Table of Contents:

1. [Analysis](#1-Analysis) <br>
    1.1. [Eccentricity](#1.1-Eccentricity) <br>
    1.2. [Centrality Measures](#1.2-Centrality-Measures) <br>
    1.3. [Small World Property](#1.3-Small-World-Property) <br>
    1.4. [Friendship Paradox](#1.4-Friendship-Paradox) <br>
    1.5. [Degree Distribution](#1.5-Degree-Distribution) <br>
    1.6. [Clustering Coefficient](#1.6-Clustering-Coefficient) <br>
    1.7. [Assortativity](#1.7-Assortativity) <br>
    1.8. [Bridges](#1.8-Bridges) <br>
    1.9. [Robustness](#1.9-Robustness) <br>
2. [Community Detection](#2-Community-Detection) <br>
3. [Dynamics](#3-Dynamics) <br>
    3.1. [SEIS Model](#3.1-SEIS-Model) <br>
    3.2. [Threshold Model](#3.2-Threshold-Model) <br>
    3.3. [Algorithmic Bias Model](#3.3-Algorithmic-Bias-Model) <br>
    3.4. [Dynamics and Communities](#3.4-Dynamics-and-Communities) <br>
    &emsp; 3.4.1. [Threshold Model](#3.4.1-Threshold-Model) <br>
    &emsp; 3.4.2. [Independent Cascades](#3.4.2-Independent-Cascades) <br>
4. [Random Models](#4-Random-Models) <br>
5. [Appendix: GEMSEC](#5-Appendix:-GEMSEC) <br>
- [End](#End)
